@@ -38,9 +38,10 @@ Example::
 from ...utils.importlib import require_modules
 
 
-required_modules = ['botocore.client']
+required_modules = ["botocore.client"]
 
 with require_modules(required_modules) as missing_modules:
     if not missing_modules:
         from .patch import patch
-        __all__ = ['patch']
+
+        __all__ = ["patch"]
